@@ -3,5 +3,7 @@ fit.LASSO <- function(response, x, cplx, ...){
    data <- as.data.frame(x)
    data$response <- response
    res <- penalized(response=response, data=data, lambda1=cplx, penalized=x, trace=FALSE, ...)
+   attr(res, "response") <- response
+   attr(res, "x") <- x
    res
 }
\ No newline at end of file
